@@ -8,6 +8,7 @@ class Label < ApplicationRecord
   include OptionallySearch
   include Sortable
   include FromUnion
+  include Presentable
 
   cache_markdown_field :description, pipeline: :single_line
 
@@ -233,6 +234,10 @@ class Label < ApplicationRecord
     attributes
   end
 
+  def present(attributes)
+    super(attributes.merge(presenter_class: ::LabelPresenter))
+  end
+
   private
 
   def issues_count(user, params = {})
