@@ -8,16 +8,24 @@ module Clusters
 
         app.make_updating!
 
+        patch
+      end
+
+      private
+
+      def patch
+        log_event(:begin_patch)
         helm_api.update(update_command)
 
+        log_event(:schedule_wait_for_patch)
         ClusterWaitForAppInstallationWorker.perform_in(
           ClusterWaitForAppInstallationWorker::INTERVAL, app.name, app.id)
       rescue Kubeclient::HttpError => e
         log_error(e)
-        app.make_update_errored!("Kubernetes error: #{e.error_code}")
+        app.make_errored!(_('Kubernetes error: %{error_code}') % { error_code: e.error_code })
       rescue StandardError => e
         log_error(e)
-        app.make_update_errored!("Can't start update process.")
+        app.make_errored!(_('Failed to update.'))
       end
     end
   end
